Index: lemon/bin_heap.h
===================================================================
--- lemon/bin_heap.h	(revision 559)
+++ lemon/bin_heap.h	(revision 584)
@@ -74,7 +74,7 @@
     /// \c PRE_HEAP (<tt>-1</tt>) to any element to be put in the heap.
     enum State {
-      IN_HEAP = 0,    ///< \e
-      PRE_HEAP = -1,  ///< \e
-      POST_HEAP = -2  ///< \e
+      IN_HEAP = 0,    ///< = 0.
+      PRE_HEAP = -1,  ///< = -1.
+      POST_HEAP = -2  ///< = -2.
     };
 
Index: lemon/concepts/graph_components.h
===================================================================
--- lemon/concepts/graph_components.h	(revision 580)
+++ lemon/concepts/graph_components.h	(revision 584)
@@ -603,5 +603,5 @@
       typedef IterableDigraphComponent Digraph;
 
-      /// \name Base iteration
+      /// \name Base Iteration
       ///
       /// This interface provides functions for iteration on digraph items.
@@ -655,5 +655,5 @@
       /// @}
 
-      /// \name Class based iteration
+      /// \name Class Based Iteration
       ///
       /// This interface provides iterator classes for digraph items.
@@ -780,5 +780,5 @@
       typedef IterableGraphComponent Graph;
 
-      /// \name Base iteration
+      /// \name Base Iteration
       ///
       /// This interface provides functions for iteration on edges.
@@ -819,5 +819,5 @@
       /// @}
 
-      /// \name Class based iteration
+      /// \name Class Based Iteration
       ///
       /// This interface provides iterator classes for edges.
Index: lemon/concepts/heap.h
===================================================================
--- lemon/concepts/heap.h	(revision 559)
+++ lemon/concepts/heap.h	(revision 584)
@@ -72,7 +72,7 @@
       /// \c PRE_HEAP (<tt>-1</tt>) to any element to be put in the heap.
       enum State {
-        IN_HEAP = 0,    ///< The "in heap" state constant.
-        PRE_HEAP = -1,  ///< The "pre heap" state constant.
-        POST_HEAP = -2  ///< The "post heap" state constant.
+        IN_HEAP = 0,    ///< = 0. The "in heap" state constant.
+        PRE_HEAP = -1,  ///< = -1. The "pre heap" state constant.
+        POST_HEAP = -2  ///< = -2. The "post heap" state constant.
       };
 
Index: lemon/dfs.h
===================================================================
--- lemon/dfs.h	(revision 492)
+++ lemon/dfs.h	(revision 584)
@@ -207,5 +207,5 @@
     typedef Dfs Create;
 
-    ///\name Named template parameters
+    ///\name Named Template Parameters
 
     ///@{
Index: lemon/dijkstra.h
===================================================================
--- lemon/dijkstra.h	(revision 559)
+++ lemon/dijkstra.h	(revision 584)
@@ -287,5 +287,5 @@
     typedef Dijkstra Create;
 
-    ///\name Named template parameters
+    ///\name Named Template Parameters
 
     ///@{
Index: lemon/graph_to_eps.h
===================================================================
--- lemon/graph_to_eps.h	(revision 559)
+++ lemon/graph_to_eps.h	(revision 584)
@@ -269,20 +269,16 @@
     ///\image html nodeshape_1.png
     ///\image latex nodeshape_1.eps "SQUARE shape (1)" width=2cm
-    ///
     SQUARE=1,
     /// = 2
     ///\image html nodeshape_2.png
     ///\image latex nodeshape_2.eps "DIAMOND shape (2)" width=2cm
-    ///
     DIAMOND=2,
     /// = 3
     ///\image html nodeshape_3.png
-    ///\image latex nodeshape_2.eps "MALE shape (4)" width=2cm
-    ///
+    ///\image latex nodeshape_3.eps "MALE shape (3)" width=2cm
     MALE=3,
     /// = 4
     ///\image html nodeshape_4.png
-    ///\image latex nodeshape_2.eps "FEMALE shape (4)" width=2cm
-    ///
+    ///\image latex nodeshape_4.eps "FEMALE shape (4)" width=2cm
     FEMALE=4
   };
Index: lemon/kruskal.h
===================================================================
--- lemon/kruskal.h	(revision 440)
+++ lemon/kruskal.h	(revision 584)
@@ -249,9 +249,9 @@
   /// \ingroup spantree
   ///
-  /// \brief Kruskal algorithm to find a minimum cost spanning tree of
+  /// \brief Kruskal's algorithm for finding a minimum cost spanning tree of
   /// a graph.
   ///
   /// This function runs Kruskal's algorithm to find a minimum cost
-  /// spanning tree.
+  /// spanning tree of a graph.
   /// Due to some C++ hacking, it accepts various input and output types.
   ///
@@ -265,7 +265,7 @@
   /// It can be one of the following choices.
   /// - An STL compatible 'Forward Container' with
-  /// <tt>std::pair<GR::Arc,X></tt> or
-  /// <tt>std::pair<GR::Edge,X></tt> as its <tt>value_type</tt>, where
-  /// \c X is the type of the costs. The pairs indicates the arcs/edges
+  /// <tt>std::pair<GR::Arc,C></tt> or
+  /// <tt>std::pair<GR::Edge,C></tt> as its <tt>value_type</tt>, where
+  /// \c C is the type of the costs. The pairs indicates the arcs/edges
   /// along with the assigned cost. <em>They must be in a
   /// cost-ascending order.</em>
@@ -274,6 +274,6 @@
   ///
   /// \retval out Here we also have a choice.
-  /// - It can be a writable \c bool arc/edge map. After running the
-  /// algorithm it will contain the found minimum cost spanning
+  /// - It can be a writable arc/edge map with \c bool value type. After
+  /// running the algorithm it will contain the found minimum cost spanning
   /// tree: the value of an arc/edge will be set to \c true if it belongs
   /// to the tree, otherwise it will be set to \c false. The value of
@@ -302,6 +302,6 @@
 
 #ifdef DOXYGEN
-  template <class Graph, class In, class Out>
-  Value kruskal(GR const& g, const In& in, Out& out)
+  template <typename Graph, typename In, typename Out>
+  Value kruskal(const Graph& g, const In& in, Out& out)
 #else
   template <class Graph, class In, class Out>
@@ -315,6 +315,4 @@
 
 
-
-
   template <class Graph, class In, class Out>
   inline typename _kruskal_bits::KruskalValueSelector<In>::Value
Index: lemon/lgf_reader.h
===================================================================
--- lemon/lgf_reader.h	(revision 559)
+++ lemon/lgf_reader.h	(revision 584)
@@ -594,5 +594,5 @@
   public:
 
-    /// \name Reading rules
+    /// \name Reading Rules
     /// @{
 
@@ -699,5 +699,5 @@
     /// @}
 
-    /// \name Select section by name
+    /// \name Select Section by Name
     /// @{
 
@@ -728,5 +728,5 @@
     /// @}
 
-    /// \name Using previously constructed node or arc set
+    /// \name Using Previously Constructed Node or Arc Set
     /// @{
 
@@ -1117,5 +1117,5 @@
   public:
 
-    /// \name Execution of the reader
+    /// \name Execution of the Reader
     /// @{
 
@@ -1390,5 +1390,5 @@
   public:
 
-    /// \name Reading rules
+    /// \name Reading Rules
     /// @{
 
@@ -1541,5 +1541,5 @@
     /// @}
 
-    /// \name Select section by name
+    /// \name Select Section by Name
     /// @{
 
@@ -1570,5 +1570,5 @@
     /// @}
 
-    /// \name Using previously constructed node or edge set
+    /// \name Using Previously Constructed Node or Edge Set
     /// @{
 
@@ -1960,5 +1960,5 @@
   public:
 
-    /// \name Execution of the reader
+    /// \name Execution of the Reader
     /// @{
 
@@ -2159,5 +2159,5 @@
   public:
 
-    /// \name Section readers
+    /// \name Section Readers
     /// @{
 
@@ -2258,5 +2258,5 @@
 
 
-    /// \name Execution of the reader
+    /// \name Execution of the Reader
     /// @{
 
@@ -2440,5 +2440,5 @@
 
 
-    /// \name Node sections
+    /// \name Node Sections
     /// @{
 
@@ -2466,5 +2466,5 @@
     /// @}
 
-    /// \name Arc/Edge sections
+    /// \name Arc/Edge Sections
     /// @{
 
@@ -2524,5 +2524,5 @@
     /// @}
 
-    /// \name Attribute sections
+    /// \name Attribute Sections
     /// @{
 
@@ -2550,5 +2550,5 @@
     /// @}
 
-    /// \name Extra sections
+    /// \name Extra Sections
     /// @{
 
@@ -2626,5 +2626,5 @@
   public:
 
-    /// \name Execution of the contents reader
+    /// \name Execution of the Contents Reader
     /// @{
 
Index: lemon/lgf_writer.h
===================================================================
--- lemon/lgf_writer.h	(revision 559)
+++ lemon/lgf_writer.h	(revision 584)
@@ -539,5 +539,5 @@
   public:
 
-    /// \name Writing rules
+    /// \name Writing Rules
     /// @{
 
@@ -642,5 +642,5 @@
     }
 
-    /// \name Section captions
+    /// \name Section Captions
     /// @{
 
@@ -669,5 +669,5 @@
     }
 
-    /// \name Skipping section
+    /// \name Skipping Section
     /// @{
 
@@ -886,5 +886,5 @@
   public:
 
-    /// \name Execution of the writer
+    /// \name Execution of the Writer
     /// @{
 
@@ -1107,5 +1107,5 @@
   public:
 
-    /// \name Writing rules
+    /// \name Writing Rules
     /// @{
 
@@ -1256,5 +1256,5 @@
     }
 
-    /// \name Section captions
+    /// \name Section Captions
     /// @{
 
@@ -1283,5 +1283,5 @@
     }
 
-    /// \name Skipping section
+    /// \name Skipping Section
     /// @{
 
@@ -1500,5 +1500,5 @@
   public:
 
-    /// \name Execution of the writer
+    /// \name Execution of the Writer
     /// @{
 
@@ -1652,5 +1652,5 @@
   public:
 
-    /// \name Section writers
+    /// \name Section Writers
     /// @{
 
@@ -1719,5 +1719,5 @@
 
 
-    /// \name Execution of the writer
+    /// \name Execution of the Writer
     /// @{
 
Index: lemon/lp_base.h
===================================================================
--- lemon/lp_base.h	(revision 576)
+++ lemon/lp_base.h	(revision 584)
@@ -53,10 +53,10 @@
     ///Possible outcomes of an LP solving procedure
     enum SolveExitStatus {
-      ///This means that the problem has been successfully solved: either
+      /// = 0. It means that the problem has been successfully solved: either
       ///an optimal solution has been found or infeasibility/unboundedness
       ///has been proved.
       SOLVED = 0,
-      ///Any other case (including the case when some user specified
-      ///limit has been exceeded)
+      /// = 1. Any other case (including the case when some user specified
+      ///limit has been exceeded).
       UNSOLVED = 1
     };
@@ -72,13 +72,13 @@
     ///Enum for \c messageLevel() parameter
     enum MessageLevel {
-      /// no output (default value)
+      /// No output (default value).
       MESSAGE_NOTHING,
-      /// error messages only
+      /// Error messages only.
       MESSAGE_ERROR,
-      /// warnings
+      /// Warnings.
       MESSAGE_WARNING,
-      /// normal output
+      /// Normal output.
       MESSAGE_NORMAL,
-      /// verbose output
+      /// Verbose output.
       MESSAGE_VERBOSE
     };
@@ -1006,5 +1006,5 @@
     const char* solverName() const {return _solverName();}
 
-    ///\name Build up and modify the LP
+    ///\name Build Up and Modify the LP
 
     ///@{
@@ -1789,13 +1789,13 @@
     /// The problem types for primal and dual problems
     enum ProblemType {
-      ///Feasible solution hasn't been found (but may exist).
+      /// = 0. Feasible solution hasn't been found (but may exist).
       UNDEFINED = 0,
-      ///The problem has no feasible solution
+      /// = 1. The problem has no feasible solution.
       INFEASIBLE = 1,
-      ///Feasible solution found
+      /// = 2. Feasible solution found.
       FEASIBLE = 2,
-      ///Optimal solution exists and found
+      /// = 3. Optimal solution exists and found.
       OPTIMAL = 3,
-      ///The cost function is unbounded
+      /// = 4. The cost function is unbounded.
       UNBOUNDED = 4
     };
@@ -1853,5 +1853,5 @@
     ///@}
 
-    ///\name Obtain the solution
+    ///\name Obtain the Solution
 
     ///@{
@@ -1975,15 +1975,14 @@
     /// The problem types for MIP problems
     enum ProblemType {
-      ///Feasible solution hasn't been found (but may exist).
+      /// = 0. Feasible solution hasn't been found (but may exist).
       UNDEFINED = 0,
-      ///The problem has no feasible solution
+      /// = 1. The problem has no feasible solution.
       INFEASIBLE = 1,
-      ///Feasible solution found
+      /// = 2. Feasible solution found.
       FEASIBLE = 2,
-      ///Optimal solution exists and found
+      /// = 3. Optimal solution exists and found.
       OPTIMAL = 3,
-      ///The cost function is unbounded
-      ///
-      ///The Mip or at least the relaxed problem is unbounded
+      /// = 4. The cost function is unbounded.
+      ///The Mip or at least the relaxed problem is unbounded.
       UNBOUNDED = 4
     };
@@ -2007,12 +2006,12 @@
     ///@}
 
-    ///\name Setting column type
+    ///\name Set Column Type
     ///@{
 
     ///Possible variable (column) types (e.g. real, integer, binary etc.)
     enum ColTypes {
-      ///Continuous variable (default)
+      /// = 0. Continuous variable (default).
       REAL = 0,
-      ///Integer variable
+      /// = 1. Integer variable.
       INTEGER = 1
     };
@@ -2035,5 +2034,5 @@
     ///@}
 
-    ///\name Obtain the solution
+    ///\name Obtain the Solution
 
     ///@{
Index: lemon/maps.h
===================================================================
--- lemon/maps.h	(revision 572)
+++ lemon/maps.h	(revision 584)
@@ -2729,6 +2729,6 @@
   /// \brief Potential difference map
   ///
-  /// PotentialMap returns the difference between the potentials of the
-  /// source and target nodes of each arc in a digraph, i.e. it returns
+  /// PotentialDifferenceMap returns the difference between the potentials of
+  /// the source and target nodes of each arc in a digraph, i.e. it returns
   /// \code
   ///   potential[gr.target(arc)] - potential[gr.source(arc)].
Index: lemon/min_cost_arborescence.h
===================================================================
--- lemon/min_cost_arborescence.h	(revision 581)
+++ lemon/min_cost_arborescence.h	(revision 584)
@@ -91,8 +91,8 @@
   /// \ingroup spantree
   ///
-  /// \brief %MinCostArborescence algorithm class.
+  /// \brief Minimum Cost Arborescence algorithm class.
   ///
   /// This class provides an efficient implementation of
-  /// %MinCostArborescence algorithm. The arborescence is a tree
+  /// Minimum Cost Arborescence algorithm. The arborescence is a tree
   /// which is directed from a given source node of the digraph. One or
   /// more sources should be given for the algorithm and it will calculate
@@ -391,5 +391,5 @@
   public:
 
-    /// \name Named template parameters
+    /// \name Named Template Parameters
 
     /// @{
@@ -631,5 +631,5 @@
     /// @}
 
-    /// \name Execution control
+    /// \name Execution Control
     /// The simplest way to execute the algorithm is to use
     /// one of the member functions called \c run(...). \n
Index: lemon/random.h
===================================================================
--- lemon/random.h	(revision 559)
+++ lemon/random.h	(revision 584)
@@ -660,5 +660,5 @@
     /// @}
 
-    ///\name Uniform distributions
+    ///\name Uniform Distributions
     ///
     /// @{
@@ -763,5 +763,5 @@
     /// @}
 
-    ///\name Non-uniform distributions
+    ///\name Non-uniform Distributions
     ///
     ///@{
@@ -939,5 +939,5 @@
     ///@}
 
-    ///\name Two dimensional distributions
+    ///\name Two Dimensional Distributions
     ///
     ///@{
Index: lemon/suurballe.h
===================================================================
--- lemon/suurballe.h	(revision 559)
+++ lemon/suurballe.h	(revision 584)
@@ -289,5 +289,5 @@
     }
 
-    /// \name Execution control
+    /// \name Execution Control
     /// The simplest way to execute the algorithm is to call the run()
     /// function.
Index: lemon/time_measure.h
===================================================================
--- lemon/time_measure.h	(revision 548)
+++ lemon/time_measure.h	(revision 584)
@@ -288,5 +288,5 @@
     Timer(bool run=true) :_running(run) {_reset();}
 
-    ///\name Control the state of the timer
+    ///\name Control the State of the Timer
     ///Basically a Timer can be either running or stopped,
     ///but it provides a bit finer control on the execution.
@@ -396,5 +396,5 @@
     ///@}
 
-    ///\name Query Functions for the ellapsed time
+    ///\name Query Functions for the Ellapsed Time
 
     ///@{
Index: tools/dimacs-solver.cc
===================================================================
--- tools/dimacs-solver.cc	(revision 569)
+++ tools/dimacs-solver.cc	(revision 584)
@@ -24,9 +24,8 @@
 ///
 /// See
-/// \verbatim
-///  dimacs-solver --help
-/// \endverbatim
+/// \code
+///   dimacs-solver --help
+/// \endcode
 /// for more info on usage.
-///
 
 #include <iostream>
Index: tools/dimacs-to-lgf.cc
===================================================================
--- tools/dimacs-to-lgf.cc	(revision 561)
+++ tools/dimacs-to-lgf.cc	(revision 584)
@@ -25,9 +25,8 @@
 ///
 /// See
-/// \verbatim
-///  dimacs-to-lgf --help
-/// \endverbatim
-/// for more info on usage.
-///
+/// \code
+///   dimacs-to-lgf --help
+/// \endcode
+/// for more info on the usage.
 
 #include <iostream>
Index: tools/lgf-gen.cc
===================================================================
--- tools/lgf-gen.cc	(revision 570)
+++ tools/lgf-gen.cc	(revision 584)
@@ -24,10 +24,8 @@
 ///
 /// See
-/// \verbatim
-///  lgf-gen --help
-/// \endverbatim
+/// \code
+///   lgf-gen --help
+/// \endcode
 /// for more info on the usage.
-///
-
 
 #include <algorithm>

Index: lemon/dimacs.h
===================================================================
--- lemon/dimacs.h	(revision 561)
+++ lemon/dimacs.h	(revision 584)
@@ -38,9 +38,14 @@
   struct DimacsDescriptor
   {
-    ///File type enum
-    enum Type
-      {
-        NONE, MIN, MAX, SP, MAT
-      };
+    ///\brief DIMACS file type enum
+    ///
+    ///DIMACS file type enum.
+    enum Type {
+      NONE,  ///< Undefined type.
+      MIN,   ///< DIMACS file type for minimum cost flow problems.
+      MAX,   ///< DIMACS file type for maximum flow problems.
+      SP,    ///< DIMACS file type for shostest path problems.
+      MAT    ///< DIMACS file type for plain graphs and matching problems.
+    };
     ///The file type
     Type type;
@@ -50,5 +55,5 @@
     int edgeNum;
     int lineShift;
-    /// Constructor. Sets the type to NONE.
+    ///Constructor. It sets the type to \c NONE.
     DimacsDescriptor() : type(NONE) {}
   };
@@ -56,8 +61,8 @@
   ///Discover the type of a DIMACS file
 
-  ///It starts seeking the beginning of the file for the problem type
-  ///and size info. The found data is returned in a special struct
-  ///that can be evaluated and passed to the appropriate reader
-  ///function.
+  ///This function starts seeking the beginning of the given file for the
+  ///problem type and size info. 
+  ///The found data is returned in a special struct that can be evaluated
+  ///and passed to the appropriate reader function.
   DimacsDescriptor dimacsType(std::istream& is)
   {
@@ -97,6 +102,5 @@
 
 
-
-  /// DIMACS minimum cost flow reader function.
+  /// \brief DIMACS minimum cost flow reader function.
   ///
   /// This function reads a minimum cost flow instance from DIMACS format,
@@ -254,5 +258,5 @@
   }
 
-  /// DIMACS maximum flow reader function.
+  /// \brief DIMACS maximum flow reader function.
   ///
   /// This function reads a maximum flow instance from DIMACS format,
@@ -288,5 +292,5 @@
   }
 
-  /// DIMACS shortest path reader function.
+  /// \brief DIMACS shortest path reader function.
   ///
   /// This function reads a shortest path instance from DIMACS format,
@@ -314,5 +318,5 @@
   }
 
-  /// DIMACS capacitated digraph reader function.
+  /// \brief DIMACS capacitated digraph reader function.
   ///
   /// This function reads an arc capacitated digraph instance from
@@ -360,9 +364,9 @@
   }
   
   /// DIMACS plain (di)graph reader function.
   ///
   /// This function reads a (di)graph without any designated nodes and
   /// maps from DIMACS format, i.e. from DIMACS files having a line
   /// starting with
   /// \code
   ///   p mat
@@ -360,9 +364,9 @@
   }
   
-  /// DIMACS plain (di)graph reader function.
-  ///
-  /// This function reads a (di)graph without any designated nodes and
-  /// maps from DIMACS format, i.e. from DIMACS files having a line
-  /// starting with
+  /// \brief DIMACS plain (di)graph reader function.
+  ///
+  /// This function reads a plain (di)graph without any designated nodes
+  /// and maps (e.g. a matching instance) from DIMACS format, i.e. from 
+  /// DIMACS files having a line starting with
   /// \code
   ///   p mat